@@ -41,11 +41,23 @@ namespace stan {
         return false;
       const std::vector<function_signature_t> sigs = sigs_map_[name];
       for (size_t i = 0; i < sigs.size(); ++i)
-        if (sig.second  == sigs[i].second)
+        if (sig.second == sigs[i].second)
           return true;
       return false;
     }
 
+    function_signature_t
+    function_signatures::get_definition(const std::string& name,
+                                        const function_signature_t& sig) {
+      const std::vector<function_signature_t> sigs = sigs_map_[name];
+      for (size_t i = 0; i < sigs.size(); ++i)
+        if (sig.second == sigs[i].second)
+          return sigs[i];
+      expr_type ill_formed = expr_type();
+      std::vector<function_arg_type> arg_types;
+      return function_signature_t(ill_formed, arg_types);
+    }
+
     bool function_signatures::discrete_first_arg(const std::string& fun)
       const {
       using std::map;
@@ -58,7 +70,7 @@ namespace stan {
       const vector<function_signature_t> sigs = it->second;
       for (size_t i = 0; i < sigs.size(); ++i) {
         if (sigs[i].second.size() == 0
-            || sigs[i].second[0].base_type_ != INT_T)
+            || sigs[i].second[0].expr_type_.base_type_ != INT_T)
           return false;
       }
       return true;
@@ -66,21 +78,22 @@ namespace stan {
 
     void function_signatures::add(const std::string& name,
                                   const expr_type& result_type,
-                                  const std::vector<expr_type>& arg_types) {
+                                  const std::vector<function_arg_type>&
+                                  arg_types) {
       sigs_map_[name].push_back(function_signature_t(result_type, arg_types));
     }
 
     void function_signatures::add(const std::string& name,
                                   const expr_type& result_type) {
-      std::vector<expr_type> arg_types;
+      std::vector<function_arg_type> arg_types;
       add(name, result_type, arg_types);
     }
 
     void function_signatures::add(const std::string& name,
                                   const expr_type& result_type,
                                   const expr_type& arg_type) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type));
       add(name, result_type, arg_types);
     }
 
@@ -88,9 +101,9 @@ namespace stan {
                                   const expr_type& result_type,
                                   const expr_type& arg_type1,
                                   const expr_type& arg_type2) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type1);
-      arg_types.push_back(arg_type2);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type1));
+      arg_types.push_back(function_arg_type(arg_type2));
       add(name, result_type, arg_types);
     }
 
@@ -99,10 +112,10 @@ namespace stan {
                                   const expr_type& arg_type1,
                                   const expr_type& arg_type2,
                                   const expr_type& arg_type3) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type1);
-      arg_types.push_back(arg_type2);
-      arg_types.push_back(arg_type3);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type1));
+      arg_types.push_back(function_arg_type(arg_type2));
+      arg_types.push_back(function_arg_type(arg_type3));
       add(name, result_type, arg_types);
     }
 
@@ -112,11 +125,11 @@ namespace stan {
                                   const expr_type& arg_type2,
                                   const expr_type& arg_type3,
                                   const expr_type& arg_type4) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type1);
-      arg_types.push_back(arg_type2);
-      arg_types.push_back(arg_type3);
-      arg_types.push_back(arg_type4);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type1));
+      arg_types.push_back(function_arg_type(arg_type2));
+      arg_types.push_back(function_arg_type(arg_type3));
+      arg_types.push_back(function_arg_type(arg_type4));
       add(name, result_type, arg_types);
     }
 
@@ -127,12 +140,12 @@ namespace stan {
                                   const expr_type& arg_type3,
                                   const expr_type& arg_type4,
                                   const expr_type& arg_type5) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type1);
-      arg_types.push_back(arg_type2);
-      arg_types.push_back(arg_type3);
-      arg_types.push_back(arg_type4);
-      arg_types.push_back(arg_type5);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type1));
+      arg_types.push_back(function_arg_type(arg_type2));
+      arg_types.push_back(function_arg_type(arg_type3));
+      arg_types.push_back(function_arg_type(arg_type4));
+      arg_types.push_back(function_arg_type(arg_type5));
       add(name, result_type, arg_types);
     }
 
@@ -144,13 +157,13 @@ namespace stan {
                                   const expr_type& arg_type4,
                                   const expr_type& arg_type5,
                                   const expr_type& arg_type6) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type1);
-      arg_types.push_back(arg_type2);
-      arg_types.push_back(arg_type3);
-      arg_types.push_back(arg_type4);
-      arg_types.push_back(arg_type5);
-      arg_types.push_back(arg_type6);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type1));
+      arg_types.push_back(function_arg_type(arg_type2));
+      arg_types.push_back(function_arg_type(arg_type3));
+      arg_types.push_back(function_arg_type(arg_type4));
+      arg_types.push_back(function_arg_type(arg_type5));
+      arg_types.push_back(function_arg_type(arg_type6));
       add(name, result_type, arg_types);
     }
 
@@ -163,14 +176,14 @@ namespace stan {
                                   const expr_type& arg_type5,
                                   const expr_type& arg_type6,
                                   const expr_type& arg_type7) {
-      std::vector<expr_type> arg_types;
-      arg_types.push_back(arg_type1);
-      arg_types.push_back(arg_type2);
-      arg_types.push_back(arg_type3);
-      arg_types.push_back(arg_type4);
-      arg_types.push_back(arg_type5);
-      arg_types.push_back(arg_type6);
-      arg_types.push_back(arg_type7);
+      std::vector<function_arg_type> arg_types;
+      arg_types.push_back(function_arg_type(arg_type1));
+      arg_types.push_back(function_arg_type(arg_type2));
+      arg_types.push_back(function_arg_type(arg_type3));
+      arg_types.push_back(function_arg_type(arg_type4));
+      arg_types.push_back(function_arg_type(arg_type5));
+      arg_types.push_back(function_arg_type(arg_type6));
+      arg_types.push_back(function_arg_type(arg_type7));
       add(name, result_type, arg_types);
     }
 
@@ -207,19 +220,19 @@ namespace stan {
 
     int function_signatures::num_promotions(
                             const std::vector<expr_type>& call_args,
-                            const std::vector<expr_type>& sig_args) {
+                            const std::vector<function_arg_type>& sig_args) {
       if (call_args.size() != sig_args.size()) {
         return -1;  // failure
       }
       int num_promotions = 0;
       for (size_t i = 0; i < call_args.size(); ++i) {
-        if (call_args[i] == sig_args[i]) {
+        if (call_args[i] == sig_args[i].expr_type_) {
           continue;
         } else if (call_args[i].is_primitive_int()
-                   && sig_args[i].is_primitive_double()) {
+                   && sig_args[i].expr_type_.is_primitive_double()) {
           ++num_promotions;
         } else {
-          return -1;  // failed match
+          return -1;    // failed match
         }
       }
       return num_promotions;
@@ -248,7 +261,6 @@ namespace stan {
     }
 
 
-
     bool is_binary_operator(const std::string& name) {
       return name == "add"
         || name == "subtract"
@@ -277,8 +289,6 @@ namespace stan {
     }
 
 
-
-
     std::string fun_name_to_operator(const std::string& name) {
       // binary infix (pow handled by parser)
       if (name == "add") return "+";
@@ -311,8 +321,43 @@ namespace stan {
       if (name.size() > OP_SIZE && name.substr(0, OP_SIZE) == "operator") {
         std::string operator_name = name.substr(OP_SIZE);
         if (arg_types.size() == 2) {
-          msgs << arg_types[0] << " " << operator_name << " " << arg_types[1]
-               << std::endl;
+          msgs << arg_types[0] << " " << operator_name << " "
+               << arg_types[1] << std::endl;
+          return;
+        } else if (arg_types.size() == 1) {
+          if (operator_name == "'")  // exception for postfix
+            msgs << arg_types[0] << operator_name << std::endl;
+          else
+            msgs << operator_name << arg_types[0] << std::endl;
+          return;
+        } else {
+          // should not be reachable due to operator grammar
+          // continue on purpose to get more info to user if this happens
+          msgs << "Operators must have 1 or 2 arguments." << std::endl;
+        }
+      }
+      if (sampling_error_style && arg_types.size() > 0)
+        msgs << arg_types[0] << " ~ ";
+      msgs << name << "(";
+      size_t start = sampling_error_style ? 1 : 0;
+      for (size_t j = start; j < arg_types.size(); ++j) {
+        if (j > start) msgs << ", ";
+        msgs << arg_types[j];
+      }
+      msgs << ")" << std::endl;
+    }
+
+    void print_signature(const std::string& name,
+                         const std::vector<function_arg_type>& arg_types,
+                         bool sampling_error_style,
+                         std::ostream& msgs) {
+      static size_t OP_SIZE = std::string("operator").size();
+      msgs << "  ";
+      if (name.size() > OP_SIZE && name.substr(0, OP_SIZE) == "operator") {
+        std::string operator_name = name.substr(OP_SIZE);
+        if (arg_types.size() == 2) {
+          msgs << arg_types[0] << " " << operator_name << " "
+               << arg_types[1] << std::endl;
           return;
         } else if (arg_types.size() == 1) {
           if (operator_name == "'")  // exception for postfix
