@@ -22,6 +22,11 @@ namespace stan {
      * from the dump format through a variable context.
      */
     struct dump_member_var_visgen : public visgen {
+      /**
+       * Indentation level.
+       */
+      size_t indent_;
+
       /**
        * Visitor for generating code to resize variables.
        */
@@ -36,11 +41,13 @@ namespace stan {
        * Construct a visitor to generate code to read member variables
        * to the specified stream.
        *
+       * @param[in] indent indentation level
        * @param[in,out] o stream for generating
        */
-      explicit dump_member_var_visgen(std::ostream& o)
-        : visgen(o), var_resizer_(var_resizing_visgen(o)),
-          var_size_validator_(var_size_validating_visgen(o,
+      explicit dump_member_var_visgen(size_t indent, std::ostream& o)
+        : visgen(o), indent_(indent),
+          var_resizer_(var_resizing_visgen(indent, o)),
+          var_size_validator_(var_size_validating_visgen(indent, o,
                                                     "data initialization")) {
       }
 
@@ -50,13 +57,13 @@ namespace stan {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_i__ = context__.vals_i(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        size_t indentation = 1;
+        generate_indent(indent_, o_);
+        o_ << "vals_i__ = context__.vals_i(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
-          ++indentation;
           generate_indent(indentation, o_);
           o_ << "size_t " << x.name_ << "_limit_" << dim << "__ = ";
           generate_expression(dims[dim], o_);
@@ -65,14 +72,15 @@ namespace stan {
           o_ << "for (size_t i_" << dim << "__ = 0; i_"
              << dim << "__ < " << x.name_ << "_limit_" << dim
              << "__; ++i_" << dim << "__) {" << EOL;
+          ++indentation;
         }
-        generate_indent(indentation+1, o_);
+        generate_indent(indentation, o_);
         o_ << x.name_;
         for (size_t dim = 0; dim < dims.size(); ++dim)
           o_ << "[i_" << dim << "__]";
         o_ << " = vals_i__[pos__++];" << EOL;
         for (size_t dim = 0; dim < dims.size(); ++dim) {
-          generate_indent(dims.size() + 1 - dim, o_);
+          generate_indent(--indentation, o_);
           o_ << "}" << EOL;
         }
       }
@@ -81,13 +89,13 @@ namespace stan {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        size_t indentation = 1;
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
-          ++indentation;
           generate_indent(indentation, o_);
           o_ << "size_t " << x.name_ << "_limit_" << dim << "__ = ";
           generate_expression(dims[dim], o_);
@@ -96,14 +104,15 @@ namespace stan {
           o_ << "for (size_t i_" << dim << "__ = 0; i_" << dim << "__ < "
              << x.name_ << "_limit_" << dim << "__; ++i_" << dim << "__) {"
              << EOL;
+          ++indentation;
         }
-        generate_indent(indentation+1, o_);
+        generate_indent(indentation, o_);
         o_ << x.name_;
         for (size_t dim = 0; dim < dims.size(); ++dim)
           o_ << "[i_" << dim << "__]";
         o_ << " = vals_r__[pos__++];" << EOL;
         for (size_t dim = 0; dim < dims.size(); ++dim) {
-          generate_indent(dims.size() + 1 - dim, o_);
+          generate_indent(--indentation, o_);
           o_ << "}" << EOL;
         }
       }
@@ -112,15 +121,18 @@ namespace stan {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_i_vec_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_i_vec_lim__ = ";
         generate_expression(x.M_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
            << x.name_ << "_i_vec_lim__; ++i_vec__) {" << EOL;
-        size_t indentation = 2;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -143,22 +155,26 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const row_vector_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_i_vec_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_i_vec_lim__ = ";
         generate_expression(x.N_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
            << x.name_ << "_i_vec_lim__; ++i_vec__) {" << EOL;
-        size_t indentation = 2;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -181,22 +197,26 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const unit_vector_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_i_vec_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_i_vec_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
            << x.name_ << "_i_vec_lim__; ++i_vec__) {" << EOL;
-        size_t indentation = 2;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -219,22 +239,26 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const simplex_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_i_vec_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_i_vec_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
            << x.name_ << "_i_vec_lim__; ++i_vec__) {" << EOL;
-        size_t indentation = 2;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -257,22 +281,26 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const ordered_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_i_vec_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_i_vec_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
            << x.name_ << "_i_vec_lim__; ++i_vec__) {" << EOL;
-        size_t indentation = 2;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -295,22 +323,26 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const positive_ordered_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_i_vec_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_i_vec_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "i_vec__ = 0; " << "i_vec__ < "
            << x.name_ << "_i_vec_lim__; ++i_vec__) {" << EOL;
-        size_t indentation = 2;
+        size_t indentation = indent_;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -333,27 +365,34 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const matrix_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2 << "vals_r__ = context__.vals_r(\""
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\""
            << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_m_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_m_mat_lim__ = ";
         generate_expression(x.M_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_n_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_n_mat_lim__ = ";
         generate_expression(x.N_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
            << x.name_ << "_n_mat_lim__; ++n_mat__) {" << EOL;
-        o_ << INDENT3 << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
+        generate_indent(indent_ + 1, o_);
+        o_ << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
            << x.name_ << "_m_mat_lim__; ++m_mat__) {" << EOL;
-        size_t indentation = 3;
+        size_t indentation = indent_ + 1;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -376,27 +415,31 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT3 << "}" << EOL;
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_ + 1, o_);
+        o_ << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const corr_matrix_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2
-           << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_k_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_k_mat_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2
-           << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < " << x.name_
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < " << x.name_
            << "_k_mat_lim__; ++n_mat__) {" << EOL;
-        o_ << INDENT3
-           << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < " << x.name_
+        generate_indent(indent_ + 1, o_);
+        o_ << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < " << x.name_
            << "_k_mat_lim__; ++m_mat__) {" << EOL;
-        size_t indentation = 3;
+        size_t indentation = indent_ + 1;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -419,32 +462,36 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT3 << "}" << EOL;
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_ + 1, o_);
+        o_ << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const cholesky_factor_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2 << "vals_r__ = context__.vals_r(\""
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\""
            << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-
-        o_ << INDENT2 << "size_t " << x.name_ << "_m_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_m_mat_lim__ = ";
         generate_expression(x.M_, o_);
         o_ << ";" << EOL;
-
-        o_ << INDENT2 << "size_t " << x.name_ << "_n_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_n_mat_lim__ = ";
         generate_expression(x.N_, o_);
         o_ << ";" << EOL;
-
-        o_ << INDENT2 << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
            << x.name_ << "_n_mat_lim__; ++n_mat__) {" << EOL;
-        o_ << INDENT3 << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
+        generate_indent(indent_ + 1, o_);
+        o_ << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
            << x.name_ << "_m_mat_lim__; ++m_mat__) {" << EOL;
-
-        size_t indentation = 3;
+        size_t indentation = indent_ + 1;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -467,32 +514,36 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT3 << "}" << EOL;
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_ + 1, o_);
+        o_ << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const cholesky_corr_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2 << "vals_r__ = context__.vals_r(\""
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\""
            << x.name_ << "\");" << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-
-        o_ << INDENT2 << "size_t " << x.name_ << "_m_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_m_mat_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-
-        o_ << INDENT2 << "size_t " << x.name_ << "_n_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_n_mat_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-
-        o_ << INDENT2 << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
            << x.name_ << "_n_mat_lim__; ++n_mat__) {" << EOL;
-        o_ << INDENT3 << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
+        generate_indent(indent_ + 1, o_);
+        o_ << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
            << x.name_ << "_m_mat_lim__; ++m_mat__) {" << EOL;
-
-        size_t indentation = 3;
+        size_t indentation = indent_ + 1;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -515,26 +566,32 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-
-        o_ << INDENT3 << "}" << EOL;
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_ + 1, o_);
+        o_ << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
 
       void operator()(const cov_matrix_var_decl& x) const {
         std::vector<expression> dims = x.dims_;
         var_size_validator_(x);
         var_resizer_(x);
-        o_ << INDENT2 << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");"
+        generate_indent(indent_, o_);
+        o_ << "vals_r__ = context__.vals_r(\"" << x.name_ << "\");"
            << EOL;
-        o_ << INDENT2 << "pos__ = 0;" << EOL;
-        o_ << INDENT2 << "size_t " << x.name_ << "_k_mat_lim__ = ";
+        generate_indent(indent_, o_);
+        o_ << "pos__ = 0;" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "size_t " << x.name_ << "_k_mat_lim__ = ";
         generate_expression(x.K_, o_);
         o_ << ";" << EOL;
-        o_ << INDENT2 << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
+        generate_indent(indent_, o_);
+        o_ << "for (size_t " << "n_mat__ = 0; " << "n_mat__ < "
            << x.name_ << "_k_mat_lim__; ++n_mat__) {" << EOL;
-        o_ << INDENT3 << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
+        generate_indent(indent_ + 1, o_);
+        o_ << "for (size_t " << "m_mat__ = 0; " << "m_mat__ < "
            << x.name_ << "_k_mat_lim__; ++m_mat__) {" << EOL;
-        size_t indentation = 3;
+        size_t indentation = indent_ + 1;
         for (size_t dim_up = 0U; dim_up < dims.size(); ++dim_up) {
           size_t dim = dims.size() - dim_up - 1U;
           ++indentation;
@@ -557,8 +614,10 @@ namespace stan {
           generate_indent(dims.size() + 2 - dim, o_);
           o_ << "}" << EOL;
         }
-        o_ << INDENT3 << "}" << EOL;
-        o_ << INDENT2 << "}" << EOL;
+        generate_indent(indent_ + 1, o_);
+        o_ << "}" << EOL;
+        generate_indent(indent_, o_);
+        o_ << "}" << EOL;
       }
     };
 
