@@ -1,7 +1,7 @@
 #ifndef STAN_MCMC_HMC_XHMC_ADAPT_SOFTABS_XHMC_HPP
 #define STAN_MCMC_HMC_XHMC_ADAPT_SOFTABS_XHMC_HPP
 
-#include <stan/callbacks/writer.hpp>
+#include <stan/callbacks/logger.hpp>
 #include <stan/mcmc/hmc/xhmc/softabs_xhmc.hpp>
 #include <stan/mcmc/stepsize_adapter.hpp>
 
@@ -21,12 +21,10 @@ namespace stan {
 
       ~adapt_softabs_xhmc() {}
 
-      sample transition(sample& init_sample,
-                        callbacks::writer& info_writer,
-                        callbacks::writer& error_writer) {
+      sample transition(sample& init_sample, callbacks::logger& logger) {
         sample s
           = softabs_xhmc<Model, BaseRNG>::transition(init_sample,
-                                                     info_writer, error_writer);
+                                                     logger);
 
         if (this->adapt_flag_)
           this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
