@@ -14,10 +14,10 @@ namespace stan {
     template<typename T, int R, int C>
     inline fvar<T>
     dot_self(const Eigen::Matrix<fvar<T>, R, C>& v) {
-      stan::math::check_vector("dot_self",
-                                         "v", v);
+      check_vector("dot_self", "v", v);
       return dot_product(v, v);
     }
+
   }
 }
 #endif
