@@ -8,10 +8,16 @@
 namespace stan {
   namespace math {
 
+    /**
+     * Returns the inverse logit function applied to the argument.
+     *
+     * @tparam T scalar type of forward-mode autodiff variable
+     * argument.
+     * @param x argument
+     * @return inverse logit of argument
+     */
     template <typename T>
-    inline
-    fvar<T>
-    inv_logit(const fvar<T>& x) {
+    inline fvar<T> inv_logit(const fvar<T>& x) {
       using std::exp;
       using std::pow;
       return fvar<T>(inv_logit(x.val_),
