@@ -16,7 +16,8 @@ namespace stan {
      */
     template <typename T>
     inline T sum(const std::vector<T>& xs) {
-      if (xs.size() == 0) return 0;
+      if (xs.size() == 0)
+        return 0;
       T sum(xs[0]);
       for (size_t i = 1; i < xs.size(); ++i)
         sum += xs[i];
