@@ -6,7 +6,6 @@
 #include <stan/math/prim/arr/meta/is_vector.hpp>
 #include <stan/math/prim/arr/meta/length.hpp>
 
-#include <stan/math/prim/mat/meta/container_view.hpp>
 #include <stan/math/prim/mat/meta/get.hpp>
 #include <stan/math/prim/mat/meta/index_type.hpp>
 #include <stan/math/prim/mat/meta/is_constant_struct.hpp>
@@ -17,8 +16,7 @@
 #include <stan/math/prim/mat/meta/seq_view.hpp>
 #include <stan/math/prim/mat/meta/scalar_type.hpp>
 #include <stan/math/prim/mat/meta/value_type.hpp>
-#include <stan/math/prim/mat/meta/VectorView.hpp>
-#include <stan/math/prim/mat/meta/VectorViewMvt.hpp>
+#include <stan/math/prim/mat/meta/vector_seq_view.hpp>
 
 #include <stan/math/prim/mat/err/check_cholesky_factor.hpp>
 #include <stan/math/prim/mat/err/check_cholesky_factor_corr.hpp>
@@ -49,9 +47,9 @@
 #include <stan/math/prim/mat/fun/acos.hpp>
 #include <stan/math/prim/mat/fun/acosh.hpp>
 #include <stan/math/prim/mat/fun/add.hpp>
+#include <stan/math/prim/mat/fun/append_array.hpp>
 #include <stan/math/prim/mat/fun/append_col.hpp>
 #include <stan/math/prim/mat/fun/append_row.hpp>
-#include <stan/math/prim/mat/fun/array_builder.hpp>
 #include <stan/math/prim/mat/fun/asin.hpp>
 #include <stan/math/prim/mat/fun/asinh.hpp>
 #include <stan/math/prim/mat/fun/assign.hpp>
@@ -171,8 +169,8 @@
 #include <stan/math/prim/mat/fun/positive_ordered_constrain.hpp>
 #include <stan/math/prim/mat/fun/positive_ordered_free.hpp>
 #include <stan/math/prim/mat/fun/prod.hpp>
-#include <stan/math/prim/mat/fun/promoter.hpp>
 #include <stan/math/prim/mat/fun/promote_common.hpp>
+#include <stan/math/prim/mat/fun/promote_elements.hpp>
 #include <stan/math/prim/mat/fun/promote_scalar.hpp>
 #include <stan/math/prim/mat/fun/promote_scalar_type.hpp>
 #include <stan/math/prim/mat/fun/qr_Q.hpp>
@@ -247,33 +245,52 @@
 #include <stan/math/prim/mat/functor/finite_diff_hessian.hpp>
 
 #include <stan/math/prim/mat/prob/categorical_log.hpp>
+#include <stan/math/prim/mat/prob/categorical_lpmf.hpp>
 #include <stan/math/prim/mat/prob/categorical_logit_log.hpp>
+#include <stan/math/prim/mat/prob/categorical_logit_lpmf.hpp>
 #include <stan/math/prim/mat/prob/categorical_rng.hpp>
+#include <stan/math/prim/mat/prob/categorical_logit_rng.hpp>
 #include <stan/math/prim/mat/prob/dirichlet_log.hpp>
+#include <stan/math/prim/mat/prob/dirichlet_lpmf.hpp>
 #include <stan/math/prim/mat/prob/dirichlet_rng.hpp>
 #include <stan/math/prim/mat/prob/gaussian_dlm_obs_log.hpp>
+#include <stan/math/prim/mat/prob/gaussian_dlm_obs_lpdf.hpp>
 #include <stan/math/prim/mat/prob/inv_wishart_log.hpp>
+#include <stan/math/prim/mat/prob/inv_wishart_lpdf.hpp>
 #include <stan/math/prim/mat/prob/inv_wishart_rng.hpp>
 #include <stan/math/prim/mat/prob/lkj_corr_cholesky_log.hpp>
+#include <stan/math/prim/mat/prob/lkj_corr_cholesky_lpdf.hpp>
 #include <stan/math/prim/mat/prob/lkj_corr_cholesky_rng.hpp>
 #include <stan/math/prim/mat/prob/lkj_corr_log.hpp>
+#include <stan/math/prim/mat/prob/lkj_corr_lpdf.hpp>
 #include <stan/math/prim/mat/prob/lkj_corr_rng.hpp>
 #include <stan/math/prim/mat/prob/lkj_cov_log.hpp>
+#include <stan/math/prim/mat/prob/lkj_cov_lpdf.hpp>
 #include <stan/math/prim/mat/prob/matrix_normal_prec_log.hpp>
+#include <stan/math/prim/mat/prob/matrix_normal_prec_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_gp_cholesky_log.hpp>
+#include <stan/math/prim/mat/prob/multi_gp_cholesky_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_gp_log.hpp>
+#include <stan/math/prim/mat/prob/multi_gp_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_normal_cholesky_log.hpp>
+#include <stan/math/prim/mat/prob/multi_normal_cholesky_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_normal_cholesky_rng.hpp>
 #include <stan/math/prim/mat/prob/multi_normal_log.hpp>
+#include <stan/math/prim/mat/prob/multi_normal_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_normal_prec_log.hpp>
+#include <stan/math/prim/mat/prob/multi_normal_prec_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_normal_rng.hpp>
 #include <stan/math/prim/mat/prob/multi_student_t_log.hpp>
+#include <stan/math/prim/mat/prob/multi_student_t_lpdf.hpp>
 #include <stan/math/prim/mat/prob/multi_student_t_rng.hpp>
 #include <stan/math/prim/mat/prob/multinomial_log.hpp>
+#include <stan/math/prim/mat/prob/multinomial_lpmf.hpp>
 #include <stan/math/prim/mat/prob/multinomial_rng.hpp>
 #include <stan/math/prim/mat/prob/ordered_logistic_log.hpp>
+#include <stan/math/prim/mat/prob/ordered_logistic_lpmf.hpp>
 #include <stan/math/prim/mat/prob/ordered_logistic_rng.hpp>
 #include <stan/math/prim/mat/prob/wishart_log.hpp>
+#include <stan/math/prim/mat/prob/wishart_lpdf.hpp>
 #include <stan/math/prim/mat/prob/wishart_rng.hpp>
 
 #include <stan/math/prim/mat/vectorize/apply_scalar_unary.hpp>
