@@ -11,7 +11,7 @@
 namespace stan {
   namespace math {
     /**
-     * Return <code>true</code> if the specified vector is unit vector.
+     * Check if the specified vector is unit vector.
      *
      * A valid unit vector is one where the square of the elements
      * summed is equal to 1. This function tests that the sum is within the
@@ -25,14 +25,13 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param theta Vector to test.
      *
-     * @return <code>true</code> if the vector is a unit vector.
      * @throw <code>std::invalid_argument</code> if <code>theta</code>
      *   is a 0-vector.
      * @throw <code>std::domain_error</code> if the vector is not a unit
      *   vector or if any element is <code>NaN</code>.
      */
     template <typename T_prob>
-    bool check_unit_vector(const char* function,
+    void check_unit_vector(const char* function,
                            const char* name,
                            const Eigen::Matrix<T_prob,
                              Eigen::Dynamic, 1>& theta) {
@@ -45,7 +44,6 @@ namespace stan {
         std::string msg_str(msg.str());
         domain_error(function, name, ssq, msg_str.c_str());
       }
-      return true;
     }
 
   }
