@@ -4,7 +4,7 @@
 #include <stan/math/prim/mat/fun/Eigen.hpp>
 #include <stan/math/prim/mat/err/check_square.hpp>
 #include <stan/math/prim/mat/err/check_symmetric.hpp>
-#include <stdexcept>
+#include <stan/math/prim/scal/err/domain_error.hpp>
 
 namespace stan {
   namespace math {
@@ -21,22 +21,18 @@ namespace stan {
       using Eigen::Dynamic;
       using Eigen::LDLT;
       using Eigen::Matrix;
-      stan::math::check_square("inverse_spd", "m", m);
-      stan::math::check_symmetric("inverse_spd", "m", m);
+      check_square("inverse_spd", "m", m);
+      check_symmetric("inverse_spd", "m", m);
       Matrix<T, Dynamic, Dynamic> mmt = T(0.5) * (m + m.transpose());
-      // mmt = T(0.5) * mmt;
-      LDLT<Matrix<T, Dynamic, Dynamic> > ldlt(mmt);  // 0.5*(m+m.transpose()));
+      LDLT<Matrix<T, Dynamic, Dynamic> > ldlt(mmt);
       if (ldlt.info() != Eigen::Success)
-        throw std::domain_error("Error in inverse_spd, LDLT "
-                                "factorization failed");
+        domain_error("invese_spd", "LDLT factor failed", "", "");
       if (!ldlt.isPositive())
-        throw std::domain_error("Error in inverse_spd, matrix "
-                                "not positive definite");
+        domain_error("invese_spd", "matrix not positive definite", "", "");
       Matrix<T, Dynamic, 1> diag_ldlt = ldlt.vectorD();
       for (int i = 0; i < diag_ldlt.size(); ++i)
         if (diag_ldlt(i) <= 0)
-          throw std::domain_error("Error in inverse_spd, matrix "
-                                  "not positive definite");
+          domain_error("invese_spd", "matrix not positive definite", "", "");
       return ldlt.solve(Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>
                         ::Identity(m.rows(), m.cols()));
     }
