@@ -2,6 +2,7 @@
 #define STAN_MATH_PRIM_SCAL_FUN_CORR_CONSTRAIN_HPP
 
 #include <stan/math/prim/scal/fun/log1m.hpp>
+#include <stan/math/prim/scal/fun/square.hpp>
 #include <cmath>
 
 namespace stan {
@@ -15,13 +16,13 @@ namespace stan {
      *
      * <p>\f$f(x) = \tanh x = \frac{\exp(2x) - 1}{\exp(2x) + 1}\f$.
      *
-     * @param x Scalar input.
-     * @return Result of transforming the input to fall between -1 and 1.
-     * @tparam T Type of scalar.
+     * @tparam T type of value
+     * @param[in] x value
+     * @return tanh transform of value
      */
     template <typename T>
     inline
-    T corr_constrain(const T x) {
+    T corr_constrain(const T& x) {
       return tanh(x);
     }
 
@@ -36,17 +37,17 @@ namespace stan {
      * <p>\f$\log | \frac{d}{dx} \tanh x  | = \log (1 - \tanh^2 x)\f$.
      *
      * @tparam T Type of scalar.
+     * @param[in] x value
+     * @param[in,out] lp log density accumulator
      */
     template <typename T>
     inline
-    T corr_constrain(const T x, T& lp) {
+    T corr_constrain(const T& x, T& lp) {
       T tanh_x = tanh(x);
-      lp += log1m(tanh_x * tanh_x);
+      lp += log1m(square(tanh_x));
       return tanh_x;
     }
 
   }
-
 }
-
 #endif
