@@ -8,23 +8,32 @@ namespace stan {
   namespace math {
 
     /**
-     * Return the exponent base 2 of the specified argument (C99).
+     * Return the exponent base 2 of the specified argument (C99,
+     * C++11).
      *
      * The exponent base 2 function is defined by
      *
      * <code>exp2(y) = pow(2.0, y)</code>.
      *
-     * @param y Value.
-     * @tparam T Type of scalar.
-     * @return Exponent base 2 of value.
+     * @param y argument.
+     * @return exponent base 2 of argument.
      */
-    template <typename T>
-    inline typename boost::math::tools::promote_args<T>::type
-    exp2(const T y) {
+    inline double exp2(double y) {
       using std::pow;
       return pow(2.0, y);
     }
 
+    /**
+     * Return the exponent base 2 of the specified argument (C99,
+     * C++11).
+     *
+     * @param y argument
+     * @return exponent base 2 of argument
+     */
+    inline double exp2(int y) {
+      return exp2(static_cast<double>(y));
+    }
+
   }
 }
 #endif
