@@ -36,7 +36,7 @@ namespace stan {
      */
     template<typename T2>
     inline T2
-    modified_bessel_first_kind(const int v, const T2 z) {
+    modified_bessel_first_kind(int v, const T2 z) {
       check_not_nan("modified_bessel_first_kind", "z", z);
 
       return boost::math::cyl_bessel_i(v, z);
