@@ -55,8 +55,7 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_inv_scale>::type
         T_partials_return;
 
-      if (!(stan::length(y)
-            && stan::length(beta)))
+      if (!(stan::length(y) && stan::length(beta)))
         return 0.0;
 
       using std::log;
