@@ -32,9 +32,7 @@ namespace stan {
 
       T_partials_return cdf(1.0);
 
-      if (!(stan::length(y)
-            && stan::length(mu)
-            && stan::length(sigma)
+      if (!(stan::length(y) && stan::length(mu) && stan::length(sigma)
             && stan::length(alpha)))
         return cdf;
 
