@@ -2,14 +2,8 @@
 #define STAN_MATH_REV_SCAL_FUN_LOG1M_EXP_HPP
 
 #include <stan/math/rev/core.hpp>
+#include <stan/math/prim/scal/fun/expm1.hpp>
 #include <stan/math/prim/scal/fun/log1m_exp.hpp>
-#include <stan/math/rev/scal/fun/calculate_chain.hpp>
-#include <cmath>
-
-#ifdef _MSC_VER
-#include <boost/math/special_functions/expm1.hpp>
-using boost::math::expm1;
-#endif
 
 namespace stan {
   namespace math {
@@ -18,15 +12,10 @@ namespace stan {
       class log1m_exp_v_vari : public op_v_vari {
       public:
         explicit log1m_exp_v_vari(vari* avi) :
-          op_v_vari(log1m_exp(avi->val_),
-                    avi) {
-        }
+          op_v_vari(log1m_exp(avi->val_), avi) {  }
+
         void chain() {
-          // derivative of
-          //   log(1-exp(x)) = -exp(x)/(1-exp(x))
-          //                 = -1/(exp(-x)-1)
-          //                 = -1/expm1(-x)
-          avi_->adj_ -= adj_ / ::expm1(-(avi_->val_));
+          avi_->adj_ -= adj_ / expm1(-(avi_->val_));
         }
       };
     }
@@ -34,9 +23,16 @@ namespace stan {
     /**
      * Return the log of 1 minus the exponential of the specified
      * variable.
+     *
+     * <p>The deriative of <code>log(1 - exp(x))</code> with respect
+     * to <code>x</code> is <code>-1 / expm1(-x)</code>.
+     *
+     * @param[in] x Argument.
+     * @return Natural logarithm of one minus the exponential of the
+     * argument. 
      */
-    inline var log1m_exp(const var& a) {
-      return var(new log1m_exp_v_vari(a.vi_));
+    inline var log1m_exp(const var& x) {
+      return var(new log1m_exp_v_vari(x.vi_));
     }
 
   }
